@@ -46,6 +46,9 @@ private Q_SLOTS:
     void testIndentOnPaste();
     void testAboutToSave();
     void testKeepUndoOverReload();
+    void testToggleComment();
+    void testInsertTextTooLargeColumn();
+    void testBug468495();
 };
 
 #endif // KATE_DOCUMENT_TEST_H
