@@ -37,18 +37,19 @@ ModeConfigPage::ModeConfigPage(QWidget *parent)
 
     // This will let us have more separation between this page and
     // the QTabWidget edge (ereslibre)
-    QVBoxLayout *layout = new QVBoxLayout;
+    QVBoxLayout *layout = new QVBoxLayout(this);
     QWidget *newWidget = new QWidget(this);
 
     ui = new Ui::FileTypeConfigWidget();
     ui->setupUi(newWidget);
 
     ui->cmbHl->addItem(i18n("<Unchanged>"), QVariant(QString()));
-    for (const auto &hl : KateHlManager::self()->modeList()) {
+    const auto modeList = KateHlManager::self()->modeList();
+    for (const auto &hl : modeList) {
         const auto section = hl.translatedSection();
-        if (!section.isEmpty())
+        if (!section.isEmpty()) {
             ui->cmbHl->addItem(section + QLatin1Char('/') + hl.translatedName(), QVariant(hl.name()));
-        else {
+        } else {
             ui->cmbHl->addItem(hl.translatedName(), QVariant(hl.name()));
         }
     }
@@ -58,28 +59,27 @@ ModeConfigPage::ModeConfigPage(QWidget *parent)
     indentationModes << KateAutoIndent::listModes();
     ui->cmbIndenter->addItems(indentationModes);
 
-    connect(ui->cmbFiletypes, SIGNAL(activated(int)), this, SLOT(typeChanged(int)));
-    connect(ui->btnNew, SIGNAL(clicked()), this, SLOT(newType()));
-    connect(ui->btnDelete, SIGNAL(clicked()), this, SLOT(deleteType()));
+    connect(ui->cmbFiletypes, qOverload<int>(&QComboBox::activated), this, &ModeConfigPage::typeChanged);
+    connect(ui->btnNew, &QPushButton::clicked, this, &ModeConfigPage::newType);
+    connect(ui->btnDelete, &QPushButton::clicked, this, &ModeConfigPage::deleteType);
     ui->btnMimeTypes->setIcon(QIcon::fromTheme(QStringLiteral("tools-wizard")));
-    connect(ui->btnMimeTypes, SIGNAL(clicked()), this, SLOT(showMTDlg()));
+    connect(ui->btnMimeTypes, &QToolButton::clicked, this, &ModeConfigPage::showMTDlg);
 
     reload();
 
-    connect(ui->edtName, SIGNAL(textChanged(QString)), this, SLOT(slotChanged()));
-    connect(ui->edtSection, SIGNAL(textChanged(QString)), this, SLOT(slotChanged()));
-    connect(ui->edtVariables, SIGNAL(textChanged(QString)), this, SLOT(slotChanged()));
-    connect(ui->edtFileExtensions, SIGNAL(textChanged(QString)), this, SLOT(slotChanged()));
-    connect(ui->edtMimeTypes, SIGNAL(textChanged(QString)), this, SLOT(slotChanged()));
-    connect(ui->sbPriority, SIGNAL(valueChanged(int)), this, SLOT(slotChanged()));
-    connect(ui->cmbHl, SIGNAL(activated(int)), this, SLOT(slotChanged()));
-    connect(ui->cmbIndenter, SIGNAL(activated(int)), this, SLOT(slotChanged()));
+    connect(ui->edtName, &QLineEdit::textChanged, this, &ModeConfigPage::slotChanged);
+    connect(ui->edtSection, &QLineEdit::textChanged, this, &ModeConfigPage::slotChanged);
+    connect(ui->edtVariables, &VariableLineEdit::textChanged, this, &ModeConfigPage::slotChanged);
+    connect(ui->edtFileExtensions, &QLineEdit::textChanged, this, &ModeConfigPage::slotChanged);
+    connect(ui->edtMimeTypes, &QLineEdit::textChanged, this, &ModeConfigPage::slotChanged);
+    connect(ui->sbPriority, qOverload<int>(&QSpinBox::valueChanged), this, &ModeConfigPage::slotChanged);
+    connect(ui->cmbHl, qOverload<int>(&QComboBox::activated), this, &ModeConfigPage::slotChanged);
+    connect(ui->cmbIndenter, qOverload<int>(&QComboBox::activated), this, &ModeConfigPage::slotChanged);
 
     // make the context help a bit easier to access
     ui->sbPriority->setToolTip(ui->sbPriority->whatsThis());
 
     layout->addWidget(newWidget);
-    setLayout(layout);
 }
 
 ModeConfigPage::~ModeConfigPage()
@@ -95,6 +95,9 @@ void ModeConfigPage::apply()
     }
 
     save();
+    if (m_lastType != -1) {
+        ui->gbProperties->setTitle(i18n("Properties of %1", ui->cmbFiletypes->itemText(m_lastType)));
+    }
 
     KTextEditor::EditorPrivate::self()->modeManager()->save(m_types);
 }
@@ -132,7 +135,7 @@ void ModeConfigPage::update()
 
     ui->cmbFiletypes->clear();
 
-    for (KateFileType *type : qAsConst(m_types)) {
+    for (KateFileType *type : std::as_const(m_types)) {
         if (!type->sectionTranslated().isEmpty()) {
             ui->cmbFiletypes->addItem(type->sectionTranslated() + QLatin1Char('/') + type->nameTranslated());
         } else {
@@ -142,7 +145,8 @@ void ModeConfigPage::update()
 
     // get current filetype from active view via the host application
     int currentIndex = 0;
-    KTextEditor::ViewPrivate *kv = qobject_cast<KTextEditor::ViewPrivate *>(KTextEditor::EditorPrivate::self()->application()->activeMainWindow()->activeView());
+    KTextEditor::ViewPrivate *kv =
+        qobject_cast<KTextEditor::ViewPrivate *>(KTextEditor::EditorPrivate::self()->application()->activeMainWindow()->activeView());
     if (kv) {
         const QString filetypeName = kv->doc()->fileType();
         for (int i = 0; i < m_types.size(); ++i) {
@@ -190,6 +194,9 @@ void ModeConfigPage::newType()
     m_types.prepend(newT);
 
     update();
+    // show new filetype so that it is immediately available for editing
+    ui->cmbFiletypes->setCurrentIndex(0);
+    typeChanged(0);
 }
 
 void ModeConfigPage::save()
@@ -198,18 +205,16 @@ void ModeConfigPage::save()
         if (!m_types[m_lastType]->hlGenerated) {
             m_types[m_lastType]->name = ui->edtName->text();
             m_types[m_lastType]->section = ui->edtSection->text();
+
+            if (!m_types[m_lastType]->sectionTranslated().isEmpty()) {
+                ui->cmbFiletypes->setItemText(m_lastType, m_types[m_lastType]->sectionTranslated() + QLatin1Char('/') + m_types[m_lastType]->nameTranslated());
+            } else {
+                ui->cmbFiletypes->setItemText(m_lastType, m_types[m_lastType]->nameTranslated());
+            }
         }
         m_types[m_lastType]->varLine = ui->edtVariables->text();
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        m_types[m_lastType]->wildcards = ui->edtFileExtensions->text().split(QLatin1Char(';'), QString::SkipEmptyParts);
-#else
         m_types[m_lastType]->wildcards = ui->edtFileExtensions->text().split(QLatin1Char(';'), Qt::SkipEmptyParts);
-#endif
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        m_types[m_lastType]->mimetypes = ui->edtMimeTypes->text().split(QLatin1Char(';'), QString::SkipEmptyParts);
-#else
         m_types[m_lastType]->mimetypes = ui->edtMimeTypes->text().split(QLatin1Char(';'), Qt::SkipEmptyParts);
-#endif
         m_types[m_lastType]->priority = ui->sbPriority->value();
         m_types[m_lastType]->hl = ui->cmbHl->itemData(ui->cmbHl->currentIndex()).toString();
 
@@ -233,7 +238,7 @@ void ModeConfigPage::typeChanged(int type)
     if (type > -1 && type < m_types.count()) {
         KateFileType *t = m_types.at(type);
 
-        ui->gbProperties->setTitle(i18n("Properties of %1", ui->cmbFiletypes->currentText()));
+        ui->gbProperties->setTitle(i18n("Properties of %1", ui->cmbFiletypes->itemText(type)));
 
         ui->gbProperties->setEnabled(true);
         ui->btnDelete->setEnabled(true);
@@ -251,10 +256,11 @@ void ModeConfigPage::typeChanged(int type)
         ui->edtSection->setEnabled(!t->hlGenerated);
 
         // activate current hl...
-        for (int i = 0; i < ui->cmbHl->count(); ++i)
+        for (int i = 0; i < ui->cmbHl->count(); ++i) {
             if (ui->cmbHl->itemData(i).toString() == t->hl) {
                 ui->cmbHl->setCurrentIndex(i);
             }
+        }
 
         // activate the right indenter
         int indenterIndex = 0;
@@ -283,12 +289,9 @@ void ModeConfigPage::typeChanged(int type)
 
 void ModeConfigPage::showMTDlg()
 {
-    QString text = i18n("Select the MimeTypes you want for this file type.\nPlease note that this will automatically edit the associated file extensions as well.");
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    QStringList list = ui->edtMimeTypes->text().split(QRegularExpression(QStringLiteral("\\s*;\\s*")), QString::SkipEmptyParts);
-#else
+    QString text =
+        i18n("Select the MimeTypes you want for this file type.\nPlease note that this will automatically edit the associated file extensions as well.");
     QStringList list = ui->edtMimeTypes->text().split(QRegularExpression(QStringLiteral("\\s*;\\s*")), Qt::SkipEmptyParts);
-#endif
     KMimeTypeChooserDialog d(i18n("Select Mime Types"), text, list, QStringLiteral("text"), this);
     if (d.exec() == QDialog::Accepted) {
         // do some checking, warn user if mime types or patterns are removed.
@@ -302,3 +305,5 @@ QString ModeConfigPage::name() const
 {
     return i18n("Modes && Filetypes");
 }
+
+#include "moc_katemodeconfigpage.cpp"
