@@ -1,22 +1,8 @@
-/*  SPDX-License-Identifier: LGPL-2.0-or-later
+/*
+    SPDX-FileCopyrightText: 2008 Paul Giannaros <paul@giannaros.org>
+    SPDX-FileCopyrightText: 2009-2018 Dominik Haumann <dhaumann@kde.org>
 
-    Copyright (C) 2008 Paul Giannaros <paul@giannaros.org>
-    Copyright (C) 2009-2018 Dominik Haumann <dhaumann@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KATE_SCRIPT_DOCUMENT_H
@@ -192,7 +178,8 @@ public:
     Q_INVOKABLE void indent(const QJSValue &jsrange, int change);
 
 private:
-    bool _isCode(int defaultStyle);
+    KTEXTEDITOR_NO_EXPORT
+    static bool _isCode(int defaultStyle);
 
     KTextEditor::DocumentPrivate *m_document;
     QJSEngine *m_engine;
