@@ -8,7 +8,7 @@
 #include "katepartdebug.h"
 #include "kateswapfile.h"
 
-#include <KIO/JobUiDelegate>
+#include <KIO/JobUiDelegateFactory>
 #include <KIO/OpenUrlJob>
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -38,9 +38,9 @@ void SwapDiffCreator::viewDiff()
     }
 
     // create all needed tempfiles
-    m_originalFile.setFileTemplate(QDir::temp().filePath(QLatin1String("katepart_XXXXXX.original")));
-    m_recoveredFile.setFileTemplate(QDir::temp().filePath(QLatin1String("katepart_XXXXXX.recovered")));
-    m_diffFile.setFileTemplate(QDir::temp().filePath(QLatin1String("katepart_XXXXXX.diff")));
+    m_originalFile.setFileTemplate(QDir::temp().filePath(QStringLiteral("katepart_XXXXXX.original")));
+    m_recoveredFile.setFileTemplate(QDir::temp().filePath(QStringLiteral("katepart_XXXXXX.recovered")));
+    m_diffFile.setFileTemplate(QDir::temp().filePath(QStringLiteral("katepart_XXXXXX.diff")));
 
     if (!m_originalFile.open() || !m_recoveredFile.open() || !m_diffFile.open()) {
         qCWarning(LOG_KTE) << "Can't open temporary files needed for diffing";
@@ -59,9 +59,7 @@ void SwapDiffCreator::viewDiff()
     // store original text in a file as utf-8 and close it
     {
         QTextStream stream(&m_originalFile);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         stream.setCodec(QTextCodec::codecForName("UTF-8"));
-#endif
         stream << recoverDoc.text();
     }
     m_originalFile.close();
@@ -73,9 +71,7 @@ void SwapDiffCreator::viewDiff()
     // store recovered text in a file as utf-8 and close it
     {
         QTextStream stream(&m_recoveredFile);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         stream.setCodec(QTextCodec::codecForName("UTF-8"));
-#endif
         stream << recoverDoc.text();
     }
     m_recoveredFile.close();
@@ -89,7 +85,7 @@ void SwapDiffCreator::viewDiff()
     // use diff from PATH only => inform if not found at all
     const QString fullDiffPath = QStandardPaths::findExecutable(QStringLiteral("diff"));
     if (fullDiffPath.isEmpty()) {
-        KMessageBox::sorry(nullptr,
+        KMessageBox::error(m_swapFile->document()->activeView(),
                            i18n("The diff command could not be found. Please make sure that "
                                 "diff(1) is installed and in your PATH."),
                            i18n("Error Creating Diff"));
@@ -100,7 +96,9 @@ void SwapDiffCreator::viewDiff()
     // try to start the diff program, might fail, too
     m_proc.start(fullDiffPath, QStringList() << QStringLiteral("-u") << m_originalFile.fileName() << m_recoveredFile.fileName());
     if (!m_proc.waitForStarted()) {
-        KMessageBox::sorry(nullptr, i18n("The diff command '%1' could not be started.").arg(fullDiffPath), i18n("Error Creating Diff"));
+        KMessageBox::error(m_swapFile->document()->activeView(),
+                           i18n("The diff command '%1' could not be started.").arg(fullDiffPath),
+                           i18n("Error Creating Diff"));
         deleteLater();
         return;
     }
@@ -131,7 +129,7 @@ void SwapDiffCreator::slotDiffFinished()
 
     // check exit status
     if (es != QProcess::NormalExit) {
-        KMessageBox::sorry(nullptr,
+        KMessageBox::error(m_swapFile->document()->activeView(),
                            i18n("The diff command failed. Please make sure that "
                                 "diff(1) is installed and in your PATH."),
                            i18n("Error Creating Diff"));
@@ -141,7 +139,7 @@ void SwapDiffCreator::slotDiffFinished()
 
     // sanity check: is there any diff content?
     if (m_diffFile.size() == 0) {
-        KMessageBox::information(nullptr, i18n("The files are identical."), i18n("Diff Output"));
+        KMessageBox::information(m_swapFile->document()->activeView(), i18n("The files are identical."), i18n("Diff Output"));
         deleteLater();
         return;
     }
@@ -151,7 +149,7 @@ void SwapDiffCreator::slotDiffFinished()
     m_diffFile.setAutoRemove(false);
 
     KIO::OpenUrlJob *job = new KIO::OpenUrlJob(QUrl::fromLocalFile(m_diffFile.fileName()), QStringLiteral("text/x-patch"));
-    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, m_swapFile->document()->activeView()));
+    job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, m_swapFile->document()->activeView()));
     job->setDeleteTemporaryFile(true); // delete the file, once the client exits
     job->start();
 
@@ -159,3 +157,5 @@ void SwapDiffCreator::slotDiffFinished()
 }
 
 // END SwapDiffCreator
+
+#include "moc_kateswapdiffcreator.cpp"
