@@ -16,30 +16,25 @@
 #include <KSyntaxHighlighting/Theme>
 
 #include "kateextendedattribute.h"
-#include "katesyntaxmanager.h"
-#include "katetextline.h"
 #include "range.h"
 #include "spellcheck/prefixstore.h"
 
 #include <QHash>
-#include <QList>
-#include <QMap>
 #include <QVector>
 
-#include <QDate>
-#include <QObject>
-#include <QPointer>
 #include <QRegularExpression>
 #include <QStringList>
 
 #include <unordered_map>
 
-class KConfig;
-
 namespace KTextEditor
 {
 class DocumentPrivate;
 }
+namespace Kate
+{
+class TextLineData;
+}
 
 /**
  * convert from KSyntaxHighlighting => KTextEditor type
@@ -122,11 +117,9 @@ public:
      *
      * @param prevLine The previous line, the context array is picked up from that if present.
      * @param textLine The text line to parse
-     * @param nextLine The next line, to check if indentation changed for indentation based folding.
      * @param ctxChanged will be set to reflect if the context changed
-     * @param tabWidth tab width for indentation based folding, if wanted, else 0
      */
-    void doHighlight(const Kate::TextLineData *prevLine, Kate::TextLineData *textLine, const Kate::TextLineData *nextLine, bool &ctxChanged, int tabWidth = 0);
+    void doHighlight(const Kate::TextLineData *prevLine, Kate::TextLineData *textLine, bool &ctxChanged);
 
     const QString &name() const
     {
@@ -213,7 +206,7 @@ public:
      * @param cursor cursor position in the given document
      * @return attribute valid at that location, default is 0
      */
-    int attributeForLocation(KTextEditor::DocumentPrivate *doc, const KTextEditor::Cursor &cursor);
+    int attributeForLocation(KTextEditor::DocumentPrivate *doc, const KTextEditor::Cursor cursor);
 
     /**
      * Get all keywords valid for the given cursor position.
@@ -221,7 +214,7 @@ public:
      * @param cursor cursor position in the given document
      * @return all keywords valid at that location
      */
-    QStringList keywordsForLocation(KTextEditor::DocumentPrivate *doc, const KTextEditor::Cursor &cursor);
+    QStringList keywordsForLocation(KTextEditor::DocumentPrivate *doc, const KTextEditor::Cursor cursor);
 
     /**
      * Is spellchecking required for the tiven cursor position?
@@ -229,7 +222,7 @@ public:
      * @param cursor cursor position in the given document
      * @return spell checking required?
      */
-    bool spellCheckingRequiredForLocation(KTextEditor::DocumentPrivate *doc, const KTextEditor::Cursor &cursor);
+    bool spellCheckingRequiredForLocation(KTextEditor::DocumentPrivate *doc, const KTextEditor::Cursor cursor);
 
     /**
      * Get highlighting mode for the given cursor position.
@@ -237,7 +230,7 @@ public:
      * @param cursor cursor position in the given document
      * @return mode valid at that location
      */
-    QString higlightingModeForLocation(KTextEditor::DocumentPrivate *doc, const KTextEditor::Cursor &cursor);
+    QString higlightingModeForLocation(KTextEditor::DocumentPrivate *doc, const KTextEditor::Cursor cursor);
 
     KTextEditor::DefaultStyle defaultStyleForAttribute(int attr) const;
 
