@@ -362,6 +362,7 @@ class KTEXTEDITOR_EXPORT KateDocumentConfig : public KateConfig
 private:
     friend class KTextEditor::EditorPrivate;
 
+    KTEXTEDITOR_NO_EXPORT
     KateDocumentConfig();
 
 public:
@@ -548,6 +549,24 @@ public:
          * Automatically detect file indentation
          */
         AutoDetectIndent,
+
+        /**
+         * Automatically save?
+         */
+        AutoSave,
+        /**
+         * Automatically save on focus lost
+         */
+        AutoSaveOnFocusOut,
+        /**
+         * Auto save interval
+         */
+        AutoSaveInteral,
+
+        /**
+         * Should we auto-reload if the old state is in version control?
+         */
+        AutoReloadIfStateIsInVersionControl
     };
 
 public:
@@ -848,7 +867,7 @@ public:
      * Based on current set eol mode.
      * @return current end of line string
      */
-    QString eolString();
+    QString eolString() const;
 
     void setEol(int mode)
     {
@@ -937,6 +956,21 @@ public:
         return value(AutoDetectIndent).toBool();
     }
 
+    bool autoSave() const
+    {
+        return value(AutoSave).toBool();
+    }
+
+    bool autoSaveOnFocusOut() const
+    {
+        return value(AutoSaveOnFocusOut).toBool();
+    }
+
+    int autoSaveInterval() const
+    {
+        return value(AutoSaveInteral).toInt();
+    }
+
 private:
     static KateDocumentConfig *s_global;
     KTextEditor::DocumentPrivate *m_doc = nullptr;
@@ -950,6 +984,7 @@ private:
     /**
      * only used in KTextEditor::EditorPrivate for the static global fallback !!!
      */
+    KTEXTEDITOR_NO_EXPORT
     KateViewConfig();
 
 public:
@@ -970,7 +1005,9 @@ public:
 
     /**
      * All known config keys
-     * Keep them sorted alphabetic for our convenience
+     * Keep them sorted alphabetically for our convenience.
+     * Keep the same order when adding config entries with addConfigEntry() in
+     * KateViewConfig::KateViewConfig() otherwise the code will assert.
      */
     enum ConfigEntryTypes {
         AllowMarkMenu,
@@ -981,6 +1018,7 @@ public:
         BackspaceRemoveComposedCharacters,
         BookmarkSorting,
         CharsToEncloseSelection,
+        ClipboardHistoryEntries,
         DefaultMarkType,
         DynWordWrapAlignIndent,
         DynWordWrapIndicators,
@@ -996,6 +1034,7 @@ public:
         ScrollBarMiniMapWidth,
         ScrollPastEnd,
         SearchFlags,
+        TabCompletion,
         ShowBracketMatchPreview,
         ShowFoldingBar,
         ShowFoldingPreview,
@@ -1019,6 +1058,16 @@ public:
         WordCompletionRemoveTail,
         ShowFocusFrame,
         ShowDocWithCompletion,
+        MultiCursorModifier,
+        ShowFoldingOnHoverOnly,
+        ShowStatusbarLineColumn,
+        ShowStatusbarDictionary,
+        ShowStatusbarInputMode,
+        ShowStatusbarHighlightingMode,
+        ShowStatusbarTabSettings,
+        ShowStatusbarFileEncoding,
+        StatusbarLineColumnCompact,
+        ShowStatusbarEOL,
     };
 
 public:
@@ -1112,6 +1161,16 @@ public:
         return value(ShowDocWithCompletion).toBool();
     }
 
+    Qt::KeyboardModifiers multiCursorModifiers() const
+    {
+        return static_cast<Qt::KeyboardModifiers>(value(MultiCursorModifier).toInt());
+    }
+
+    void setMultiCursorModifiers(Qt::KeyboardModifiers m)
+    {
+        setValue(MultiCursorModifier, (int)m);
+    }
+
     bool iconBar() const
     {
         return value(ShowIconBar).toBool();
@@ -1214,6 +1273,11 @@ public:
         return value(AutomaticCompletionPreselectFirst).toBool();
     }
 
+    bool tabCompletion() const
+    {
+        return value(TabCompletion).toBool();
+    }
+
     bool wordCompletion() const
     {
         return value(WordCompletion).toBool();
@@ -1249,6 +1313,11 @@ public:
         return value(MousePasteAtCursorPosition).toBool();
     }
 
+    int clipboardHistoryEntries() const
+    {
+        return value(ClipboardHistoryEntries).toInt();
+    }
+
     bool scrollPastEnd() const
     {
         return value(ScrollPastEnd).toBool();
@@ -1298,6 +1367,11 @@ public:
         return value(BackspaceRemoveComposedCharacters).toBool();
     }
 
+    bool showFoldingOnHoverOnly() const
+    {
+        return value(ShowFoldingOnHoverOnly).toBool();
+    }
+
 private:
     static KateViewConfig *s_global;
     KTextEditor::ViewPrivate *m_view = nullptr;
@@ -1311,6 +1385,7 @@ private:
     /**
      * only used in KTextEditor::EditorPrivate for the static global fallback !!!
      */
+    KTEXTEDITOR_NO_EXPORT
     KateRendererConfig();
 
 public:
@@ -1425,7 +1500,7 @@ public:
     bool showWholeBracketExpression() const;
     void setShowWholeBracketExpression(bool on);
 
-    bool animateBracketMatching() const;
+    static bool animateBracketMatching();
     void setAnimateBracketMatching(bool on);
 
     const QColor &templateBackgroundColor() const;
@@ -1445,10 +1520,18 @@ public:
     const QColor &replaceHighlightColor() const;
     void setReplaceHighlightColor(const QColor &col);
 
+    void setLineHeightMultiplier(qreal value);
+
+    qreal lineHeightMultiplier() const
+    {
+        return s_global->m_lineHeightMultiplier;
+    }
+
 private:
     /**
      * Read the schema properties from the config file.
      */
+    KTEXTEDITOR_NO_EXPORT
     void setSchemaInternal(const QString &schema);
 
     QString m_schema;
@@ -1478,6 +1561,8 @@ private:
     QColor m_searchHighlightColor;
     QColor m_replaceHighlightColor;
 
+    qreal m_lineHeightMultiplier = 1.0;
+
     bool m_wordWrapMarker = false;
     bool m_showIndentationLines = false;
     bool m_showWholeBracketExpression = false;
