@@ -15,6 +15,11 @@
 using namespace KTextEditor;
 
 Range Range::fromString(const QStringRef &str) Q_DECL_NOEXCEPT
+{
+    return fromString(QStringView(str));
+}
+
+Range Range::fromString(QStringView str) Q_DECL_NOEXCEPT
 {
     const int startIndex = str.indexOf(QLatin1Char('['));
     const int endIndex = str.indexOf(QLatin1Char(']'));
@@ -44,13 +49,13 @@ void Range::setRange(const Cursor &start, const Cursor &end) Q_DECL_NOEXCEPT
 
 bool Range::confineToRange(const Range &range) Q_DECL_NOEXCEPT
 {
-    if (start() < range.start())
+    if (start() < range.start()) {
         if (end() > range.end()) {
             setRange(range);
         } else {
             setStart(range.start());
         }
-    else if (end() > range.end()) {
+    } else if (end() > range.end()) {
         setEnd(range.end());
     } else {
         return false;
@@ -61,13 +66,13 @@ bool Range::confineToRange(const Range &range) Q_DECL_NOEXCEPT
 
 bool Range::expandToRange(const Range &range) Q_DECL_NOEXCEPT
 {
-    if (start() > range.start())
+    if (start() > range.start()) {
         if (end() < range.end()) {
             setRange(range);
         } else {
             setStart(range.start());
         }
-    else if (end() < range.end()) {
+    } else if (end() < range.end()) {
         setEnd(range.end());
     } else {
         return false;
@@ -86,17 +91,43 @@ void KTextEditor::Range::setBothColumns(int column) Q_DECL_NOEXCEPT
     setRange(Range(start().line(), column, end().line(), column));
 }
 
+LineRange LineRange::fromString(QStringView str) Q_DECL_NOEXCEPT
+{
+    // parse format "[start, end]"
+    const int startIndex = str.indexOf(QLatin1Char('['));
+    const int endIndex = str.indexOf(QLatin1Char(']'));
+    const int commaIndex = str.indexOf(QLatin1Char(','));
+
+    if (startIndex < 0 || endIndex < 0 || commaIndex < 0 || commaIndex < startIndex || endIndex < commaIndex || endIndex < startIndex) {
+        return invalid();
+    }
+
+    bool ok1 = false;
+    bool ok2 = false;
+
+    const int start = str.mid(startIndex + 1, commaIndex - startIndex - 1).toString().toInt(&ok1); // FIXME KF6: Qt 5.15.2 and higher: remove .toString()
+    const int end = str.mid(commaIndex + 1, endIndex - commaIndex - 1).toString().toInt(&ok2); // FIXME KF6: Qt 5.15.2 and higher: remove .toString()
+
+    if (!ok1 || !ok2) {
+        return invalid();
+    }
+
+    return {start, end};
+}
+
 namespace QTest
 {
 // Cursor: template specialization for QTest::toString()
-template<> char *toString(const KTextEditor::Cursor &cursor)
+template<>
+char *toString(const KTextEditor::Cursor &cursor)
 {
     QByteArray ba = "Cursor[" + QByteArray::number(cursor.line()) + ", " + QByteArray::number(cursor.column()) + ']';
     return qstrdup(ba.data());
 }
 
 // Range: template specialization for QTest::toString()
-template<> char *toString(const KTextEditor::Range &range)
+template<>
+char *toString(const KTextEditor::Range &range)
 {
     QByteArray ba = "Range[";
     ba += QByteArray::number(range.start().line()) + ", " + QByteArray::number(range.start().column()) + " - ";
@@ -104,4 +135,14 @@ template<> char *toString(const KTextEditor::Range &range)
     ba += ']';
     return qstrdup(ba.data());
 }
+
+// LineRange: template specialization for QTest::toString()
+template<>
+char *toString(const KTextEditor::LineRange &range)
+{
+    QByteArray ba = "LineRange[";
+    ba += QByteArray::number(range.start()) + ", " + QByteArray::number(range.end());
+    ba += ']';
+    return qstrdup(ba.data());
+}
 }
