@@ -27,10 +27,6 @@ KateTextPreview::KateTextPreview(KTextEditor::ViewPrivate *view, QWidget *parent
 {
 }
 
-KateTextPreview::~KateTextPreview()
-{
-}
-
 KTextEditor::ViewPrivate *KateTextPreview::view() const
 {
     return m_view;
@@ -143,3 +139,5 @@ void KateTextPreview::paintEvent(QPaintEvent *event)
         paint.translate(0, lineHeight);
     }
 }
+
+#include "moc_katetextpreview.cpp"
