@@ -57,7 +57,8 @@ public:
     }
 
 private:
-    KSharedConfigPtr config() const;
+    KTEXTEDITOR_NO_EXPORT
+    static KSharedConfigPtr config();
 
 private:
     Macros *m_macros;
